#version 150

#define MAX_LIGHTS 10

// Input vertex data, different for all executions of this shader.
in vec4 vert_position;
layout(std140) uniform TransformationMatrices
{
    mat4 camera_matrix;
    mat4 persp_matrix;
};
uniform mat4 model_matrix;
uniform mat4 inv_model_matrix;

struct PointLight {
    vec4 position;
    vec4 intensity;
    vec4 specular_color;
    float constant_attenuation;
    float linear_attenuation;
    float quadratic_attenuation;
};

layout(std140) uniform PointLights
{
    PointLight point_lights[MAX_LIGHTS];
};

uniform uint num_point_lights;

struct spot {
	vec4 position;
	vec4 intensity;
    vec4 direction;
    vec4 specular_color;
    float exp;
    float constant_attenuation;
    float linear_attenuation;
    float quadratic_attenuation;
    float cos_opening;
};

layout(std140) uniform SpotLights
{
	spot spot_lights[MAX_LIGHTS];
};

uniform uint num_spot_lights;

void main(){
	vec4 light_pos = vec4(1.0f);
	vec4 vertex_pos = vert_position;
	if(int(num_spot_lights) > 0){
		light_pos = inv_model_matrix*spot_lights[0].position;
	}else{
		light_pos = inv_model_matrix*point_lights[0].position;
	}
	if(vert_position.w == 0){
		vertex_pos = vec4(vertex_pos.xyz * light_pos.w - light_pos.xyz, 0);
	}
	
	gl_Position =  persp_matrix * camera_matrix * model_matrix * vertex_pos; 

}
